--[[

Version 0.01 - Initial release of Concept code to wowace svn

Version 0.10 - Can now detect events, populate dropdown and display details of selected event including icon.

Author : Levva of EU Khadgar 
	
--]]

local L = LibStub("AceLocale-3.0"):GetLocale("RaidInviter")
local AceAddon = LibStub("AceAddon-3.0")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");
RaidInviter = AceAddon:NewAddon("RaidInviter", "AceConsole-3.0", "AceEvent-3.0")
local REVISION = tonumber(("$Revision: 19 $"):match("%d+"))

RaidInviter.textures = {}
RaidInviter.borders = {}
RaidInviter.fonts = {}
RaidInviter.sounds = {}
RaidInviter.dialogBackdrop ={
		bgFile = "Interface/DialogFrame/UI-DialogBox-Background",
		edgeFile= "Interface/DialogFrame/UI-DialogBox-Border",
		tile = true, tileSize = 32, edgeSize = 32,
		insets = { left = 11, right = 12, top = 12, bottom = 11 }
	}
RaidInviter.tooltipBackdrop ={
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		edgeFile= "Interface/Tooltips/UI-Tooltip-Border",
		tile = true, tileSize = 32, edgeSize = 32,
		insets = { left = 5, right = 5, top = 5, bottom = 5 }
	}

-------------------
-- Config details
-------------------

RaidInviter.defaults = {
	char = {
		message = "Welcome Home!",
		relativeTo = "UIParent",
		relativePoint = "CENTER",
		point = "CENTER",
		texture = "Blizzard",
		msgfont = "Friz Quadrata TT",
		msgfontsize = 24,
		msgfonteffect = "none",
		border = "None",
		barborder = "Blizzard Tooltip",
		xOffset = 0,
		yOffset = 0,
		scale = 1,
		debug = false,
	}
}

RaidInviter.inviteStatus = { }

-----------------------------------------
-- Initialisation & Startup Routines
-----------------------------------------

function RaidInviter:OnInitialize()
	local AceConfigReg = LibStub("AceConfigRegistry-3.0")
	local AceConfigDialog = LibStub("AceConfigDialog-3.0")

	self.db = LibStub("AceDB-3.0"):New("RaidInviterDBPC", RaidInviter.defaults, "char")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("RaidInviter", self:GetOptions(), {"RaidInviter", "ri"} )
	media.RegisterCallback(self, "LibSharedMedia_Registered")
	
	-- Add the options to blizzard frame (add them backwards so they show up in the proper order
	self.optionsFrame = AceConfigDialog:AddToBlizOptions("RaidInviter","RaidInviter")
	self.optionsFrame[L["About"]] = LibStub("LibAboutPanel").new("RaidInviter", "RaidInviter")
	self.db:RegisterDefaults(self.defaults)
	self:InitialiseInviteStatus()
	local version = GetAddOnMetadata("RaidInviter","Version")
	self.version = ("RaidInviter v%s (r%s)"):format(version, REVISION)
	self:Print(self.version.." Loaded.")
end

function RaidInviter:OnDisable()
    -- Called when the addon is disabled
end

function RaidInviter:OnEnable()
	self:LibSharedMedia_Registered()
	self:RegisterEvent("UPDATE_BINDINGS")
	self:RegisterEvent("GUILD_ROSTER_UPDATE")
	self:RegisterEvent("PARTY_MEMBERS_CHANGED")
	self:RegisterEvent("CALENDAR_OPEN_EVENT")
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
--~ 	self:RegisterEvent("CALENDAR_UPDATE_EVENT")
--~ 	self:RegisterEvent("CALENDAR_UPDATE_EVENT_LIST")
--~ 	self:RegisterEvent("CALENDAR_UPDATE_INVITE_LIST")
--~ 	self:RegisterEvent("CALENDAR_UPDATE_PENDING_INVITES")
end

function RaidInviter:LibSharedMedia_Registered()
	for k, v in pairs(media:List("statusbar")) do
		self.textures[v] = v
	end
	for k, v in pairs(media:List("border")) do
		self.borders[v] = v
	end
	for k, v in pairs(media:List("font")) do
		self.fonts[v] = v
	end
	for k, v in pairs(media:List("sound")) do
		self.sounds[v] = v
	end
end

function RaidInviter:InitialiseInviteStatus()
--	colour 0 = none, white, 1 = invited, yellow, 2 = declined, orange, 3 = offline, red, 4 = inraid, green
	self.inviteStatus[0] = { description = "None", col = { r=1, b=1, g=1 } }
	self.inviteStatus[1] = { description = "Invited", col = { r=1, b=1, g=1 } }
	self.inviteStatus[2] = { description = "Declined", col = { r=1, b=1, g=1 } }
	self.inviteStatus[3] = { description = "Offline", col = { r=1, b=1, g=1 } }
	self.inviteStatus[4] = { description = "In Raid", col = { r=0, b=0, g=1 } }
end

----------------------
-- Event Routines
----------------------

function RaidInviter:PLAYER_ENTERING_WORLD()
	self.weekday, self.month, self.day, self.year = CalendarGetDate()
	if not self.InviteFrame then -- only initialise on login not re-zoning
		self:CreateInviteFrame()
		self.selectedEvent = {}
		self.selectedEvent.players = {}
	end
end

function RaidInviter:UPDATE_BINDINGS()
--~ 	self:UpdateBindings()
end

function RaidInviter:GUILD_ROSTER_UPDATE()
	self.guildRoster = {}
	local guildMembers = GetNumGuildMembers(true)
	for index = 1, guildMembers do
		local name, rank, rankIndex, level, class, zone, note, officernote, online, status = GetGuildRosterInfo(index)
		if name then 
			self:DebugPrint("added "..name.." to guild roster list")
			self.guildRoster[name] = {}
			self.guildRoster[name].name = name
			self.guildRoster[name].rank = rank
			self.guildRoster[name].level = level
			self.guildRoster[name].zone = zone
			self.guildRoster[name].note = note or ""
			self.guildRoster[name].officernote = officernote or ""
			self.guildRoster[name].online = online
			self.guildRoster[name].status = status  -- "<AFK>", "<DND>", or ""
			self.guildRoster[name].lastonline = GetGuildRosterLastOnline(index)
		end
	end
	if self.InviteFrame:IsVisible() then
		self:UpdateInviteFrameWithGuildInfo()
	end
end

function RaidInviter:PARTY_MEMBERS_CHANGED()
	-- this fires when someone joins or leaves the raid or players are moved around in the raid
	-- when it fires we need to update the invite frame with their new status
end

function RaidInviter:CALENDAR_OPEN_EVENT()
	local info = UIDropDownMenu_CreateInfo()
	local title, description, creator, eventType, instanceID, ownerFlag, _, weekday, month, day, year, hour, minute = CalendarGetEventInfo()
	local monthOffset, day, index = CalendarGetEventIndex()
	if eventType == CALENDAR_EVENTTYPE_RAID or eventType == CALENDAR_EVENTTYPE_DUNGEON then
		-- TODO setup event info frame with descriptions etc
		local invites = CalendarEventGetNumInvites()
		self:DebugPrint("Calendar_OE : invites :"..invites)
		if not self.todaysEvents then
			self.todaysEvents = {}
		end
		self.todaysEvents[index] = {}
		self.todaysEvents[index].numplayers = invites
		self.todaysEvents[index].players = {}
		for player = 1, invites do
			local name, level, className, classTexture, signupStatus, modStatus = CalendarEventGetInvite(player)
			self:DebugPrint("Calendar_OE : name :"..name.." level:"..level.." className: "..className.." signupstatus:"..signupStatus.." modStatus:"..modStatus)
			--~ CALENDAR_INVITESTATUS_INVITED   = 1
			--~ CALENDAR_INVITESTATUS_ACCEPTED  = 2
			--~ CALENDAR_INVITESTATUS_DECLINED  = 3
			--~ CALENDAR_INVITESTATUS_CONFIRMED = 4
			--~ CALENDAR_INVITESTATUS_OUT       = 5
			--~ CALENDAR_INVITESTATUS_STANDBY   = 6
			--~ 	modStatus = "MODERATOR", "CREATOR", "" 
			self.todaysEvents[index].players[name] = {}
			self.todaysEvents[index].players[name].index = player
			self.todaysEvents[index].players[name].name = name
			self.todaysEvents[index].players[name].level = level
			self.todaysEvents[index].players[name].className = className
			self.todaysEvents[index].players[name].classTexture = classTexture
			self.todaysEvents[index].players[name].signupStatus = signupStatus
			self.todaysEvents[index].players[name].modStatus = modStatus
			self.todaysEvents[index].players[name].inviteStatus = 0 -- need a table with description, colour 0 = none, white, 1 = invited, yellow, 2 = declined, orange, 3 = offline, red, 4 = inraid, green
		end
	end
end

----------------------
-- Frame Routines
----------------------

function RaidInviter:CreateInviteFrame()
	local frameWidth = 800
	self.InviteFrame = CreateFrame("Frame", "RaidInviterBase", UIParent)
	self.InviteFrame:SetScale(self.db.char.scale)
	self.InviteFrame:SetFrameStrata("MEDIUM")
	self.InviteFrame:SetWidth(frameWidth)
	self.InviteFrame:SetHeight(600)
	self.InviteFrame:SetBackdrop(self.tooltipBackdrop)
	self.InviteFrame:SetMovable(true)
	self.InviteFrame:SetToplevel(true)
	self.InviteFrame:EnableMouse(true)
	self.InviteFrame:RegisterForDrag("LeftButton")
	self.InviteFrame:SetPoint(self.db.char.point, self.db.char.relativeTo, self.db.char.relativePoint, self.db.char.xOffset, self.db.char.yOffset)
	self.InviteFrame:SetScript("OnHide", function() self:RaidInviter_OnHide() end)
	self.InviteFrame:SetScript("OnDragStart", 
		function()
			self.InviteFrame:StartMoving();
		end );
	self.InviteFrame:SetScript("OnDragStop",
		function()
			self.InviteFrame:StopMovingOrSizing();
			self.InviteFrame:SetScript("OnUpdate", nil);
			self:FinishedMoving(self.db.char, self.InviteFrame);
		end );
	self.InviteFrame:SetBackdropColor(0, 0, 0, 1)
	self.InviteFrame.textureFrame = CreateFrame("Frame", nil, self.InviteFrame)
	self.InviteFrame.textureFrame:SetBackdrop(self.tooltipBackdrop)
	self.InviteFrame.textureFrame:SetBackdropColor(0, 0, 0, 1)
	self.InviteFrame.textureFrame:SetWidth(frameWidth)
	self.InviteFrame.textureFrame:SetHeight(12)
	self.InviteFrame.textureFrame:SetPoint("TOP", self.InviteFrame, "TOP", 0, -28)
	self.InviteFrame.textureFrame:Show()
	
	self.InviteFrame.headertext = self.InviteFrame.textureFrame:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	self.InviteFrame.headertext:ClearAllPoints()
	self.InviteFrame.headertext:SetWidth(frameWidth)
	self.InviteFrame.headertext:SetHeight(12)
	self.InviteFrame.headertext:SetPoint("CENTER", self.InviteFrame, "TOP", 0, -18)
--~ 	self.InviteFrame.headertext:SetFont("Friz Quadrata TT", 24)
	self.InviteFrame.headertext:SetText("Raid Inviter")
	local closeButton = CreateFrame("Button", nil, self.InviteFrame, "UIPanelCloseButton")
	closeButton:SetScript("OnClick", function() self:RaidInviter_OnHide() end)
	closeButton:SetPoint("TOPRIGHT", self.InviteFrame, "TOPRIGHT", 0, -1)
	closeButton:SetScale(1.2)

	self:CreateEventInfoFrame()
	self:CreateEventListDropdown()
	self:CreatePlayerListFrame()
	self:CreateRaidCompositionFrames()
	if not self.db.char.debug then
		self.InviteFrame:Hide()
	end
end

function RaidInviter:CreateEventInfoFrame()
	if not self.InviteFrame.event then
		self.InviteFrame.event =  CreateFrame("Frame", "RaidInviterEventInfo", self.InviteFrame)
	end
	self.InviteFrame.event:ClearAllPoints()
	self.InviteFrame.event:SetWidth(750)
	self.InviteFrame.event:SetHeight(80)
	self.InviteFrame.event:SetBackdrop({
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		--edgeFile= "Interface/Tooltips/UI-Tooltip-Border",
		tile = true, tileSize = 32, edgeSize = 32,
		insets = { left = 5, right = 5, top = 5, bottom = 5 }
	})
	self.InviteFrame.event:SetPoint("CENTER", self.InviteFrame, "TOP", 0, -90)
	self.InviteFrame.event:SetBackdropColor(0, 0, 0, 0)
	
	if not self.InviteFrame.event.title then
		self.InviteFrame.event.title = self.InviteFrame.event:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	end
	self.InviteFrame.event.title:SetFont("Friz Quadrata TT", 14)
	self.InviteFrame.event.title:SetTextColor(1, 1, 1, 1)
	self.InviteFrame.event.title:SetPoint("TOPLEFT", self.InviteFrame.event, "TOPLEFT", 77, -50)
	self.InviteFrame.event.title:SetText("Event : ")
	
	if not self.InviteFrame.event.time then
		self.InviteFrame.event.time = self.InviteFrame.event:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	end
	self.InviteFrame.event.time:SetFont("Friz Quadrata TT", 14)
	self.InviteFrame.event.time:SetTextColor(1, 1, 1, 1)
	self.InviteFrame.event.time:SetPoint("TOPLEFT", self.InviteFrame.event, "TOPLEFT", 77, -75)
	self.InviteFrame.event.time:SetText("Time : ")

	if not self.InviteFrame.event.icon then
		self.InviteFrame.event.icon = CreateFrame("Frame", "RaidInviterEventIcon", self.InviteFrame.event)
	end
	self.InviteFrame.event.icon:SetBackdropColor(0, 0, 0, 1)
	self.InviteFrame.event.icon:SetWidth(50)
	self.InviteFrame.event.icon:SetHeight(50)
	self.InviteFrame.event.icon:SetPoint("TOPLEFT", self.InviteFrame.event, "TOPLEFT", 10, -40)
	self:SetEventIcon("Interface/Tooltips/UI-Tooltip-Background")	
	self.InviteFrame.event.icon:SetBackdropColor(0, 0, 0, 0.5)
	self.InviteFrame.event.icon:Show()
	
	self.InviteFrame.event:Show()
end

function RaidInviter:SetEventIcon(icon)
	self.InviteFrame.event.icon:SetBackdrop({ bgFile = icon,
		edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	})
end


function RaidInviter:CreateEventListDropdown()
	if not self.InviteFrame.event.dropdown then
		self.InviteFrame.event.dropdown = CreateFrame("Frame", "RaidInviterEventList", self.InviteFrame.event, "UIDropDownMenuTemplate")
	end
	self.InviteFrame.event.dropdown:SetPoint("CENTER", self.InviteFrame.event, "TOP", 5 , -20)
	UIDropDownMenu_SetWidth(self.InviteFrame.event.dropdown, 200)
	UIDropDownMenu_Initialize(self.InviteFrame.event.dropdown, function(self) RaidInviter:PopulateEventList() end)
	self.InviteFrame.event.dropdown.text = self.InviteFrame.event:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
	self.InviteFrame.event.dropdown.text:SetFont("Friz Quadrata TT", 14)
	self.InviteFrame.event.dropdown.text:SetTextColor(1, 1, 1, 1)
	self.InviteFrame.event.dropdown.text:SetPoint("RIGHT", self.InviteFrame.event.dropdown, "LEFT", 0, 2)
	self.InviteFrame.event.dropdown.text:SetText(L["Select Event"])
	self.InviteFrame.event.dropdown:Show()
end

function RaidInviter:PopulateEventList()
	local info = UIDropDownMenu_CreateInfo()
	local eventsToday = CalendarGetNumDayEvents(0, self.day)
	self:DebugPrint("day : "..self.day.." found "..eventsToday.." events today")
	local uiEvents = 0
	if eventsToday > 0 then
		for index = 1, eventsToday do
			local title, _, _,  _, _, eventType = CalendarGetDayEvent( 0, self.day, index ) 
			self:DebugPrint("found event type:"..eventType.." title : "..title)
			if eventType == 1 then -- CALENDAR_EVENTTYPE_RAID
				info.text = title
				info.value = index
				info.func = function() RaidInviter:EventListItem_OnClick() end
				info.owner = self.InviteFrame.event.dropdown
				info.checked = false
				info.icon = nil
				UIDropDownMenu_AddButton(info)
				uiEvents = uiEvents + 1
			end
		end
	end
	if uiEvents == 0 then
		info.text = "No scheduled events today"
		info.value = -1 
		info.func = nil
		info.owner = self.InviteFrame.event.dropdown
		info.checked = true
		info.icon = nil
		UIDropDownMenu_AddButton(info)
	end
end

function RaidInviter:CreatePlayerListFrame()
	if not self.InviteFrame.playerList then
		self.InviteFrame.playerList = CreateFrame("ScrollFrame", "RaidInviterPlayerListScroll", self.InviteFrame, "FauxScrollFrameTemplate")
	end
	self.InviteFrame.playerList:ClearAllPoints()
	self.InviteFrame.playerList:SetWidth(750)
	self.InviteFrame.playerList:SetHeight(350)
	self.InviteFrame.playerList:SetBackdrop({
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		edgeFile= "Interface/Tooltips/UI-Tooltip-Border",
		tile = true, tileSize = 16, edgeSize = 16,
		insets = { left = 5, right = 5, top = 5, bottom = 5 }
	})
	self.InviteFrame.playerList:SetPoint("TOPLEFT", self.InviteFrame.event, "BOTTOMLEFT", -10, -20)
	self.InviteFrame.playerList:SetBackdropColor(0, 0, 0, 0.2)
	self.InviteFrame.playerList:Show()
	
	local function updateScroll()
		self:PlayerFrameScroll()
	end

	self.InviteFrame.playerList:SetScript("OnVerticalScroll",
		function(self, offset)
			FauxScrollFrame_OnVerticalScroll(self, offset, 16, updateScroll)
		end )
	self.InviteFrame.playerList:SetScript("OnShow", function() RaidInviter:PlayerFrameScroll() end )
	
	self.InviteFrame.playerList.lines = {}

	function self.InviteFrame.playerList:Clear()
		for i = 1, #self.InviteFrame.playerList.lines do
			local line = self.InviteFrame.playerList.lines[i]
			line.nameText = nil
			line.classText = nil
			line.rankText = nil
			line.zoneText = nil
			line.signupText = nil
			line.onlineText = nil
			line.inviteText = nil
		end
	end
end

function RaidInviter:PlayerFrameScroll()
	FauxScrollFrame_Update(self.InviteFrame.playerList, #self.InviteFrame.playerList.lines, 25, 14) -- scrollframe, number in list, number to display, fontsize of line
	local startline = FauxScrollFrame_GetOffset(self.InviteFrame.playerList)
	if startline > 0 then
		self:PopulatePlayerFrame(startline)
	end
end

function RaidInviter:PopulatePlayerFrame(startline)
	local textHeight = 0
	local endline = startline + 19
	local textline = 0
	if endline > #self.InviteFrame.playerList.lines then
		endline = #self.InviteFrame.playerList.lines
	end
	for i = startline, endline do
		textline = i - startline + 1
		if not self.InviteFrame.playerList.lines[textline] then
			self.InviteFrame.playerList.lines[textline] = {}
			local nameText = self.InviteFrame.playerList:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			nameText:SetFont("Friz Quadrata TT", 14)
			if textline == 1 then
				nameText:SetPoint("TOPRIGHT", self.InviteFrame.playerList, "TOPLEFT", 125, -35)
			else
				nameText:SetPoint("TOPRIGHT", self.InviteFrame.playerList.lines[textline-1], "BOTTOMRIGHT", 0, -1)
			end
			self.InviteFrame.playerList.lines[textline].nameText = nameText

			local classText = self.InviteFrame.playerList:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			classText:SetFont("Friz Quadrata TT", 14)
			classText:SetPoint("LEFT", left, "RIGHT", 5, 0)
			self.InviteFrame.playerList.lines[textline].classText = classText

			local rankText = self.InviteFrame.playerList:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			rankText:SetFont("Friz Quadrata TT", 14)
			rankText:SetPoint("LEFT", left, "RIGHT", 5, 0)
			self.InviteFrame.playerList.lines[textline].rankText = rankText

			local zoneText = self.InviteFrame.playerList:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			zoneText:SetFont("Friz Quadrata TT", 14)
			zoneText:SetPoint("LEFT", left, "RIGHT", 5, 0)
			self.InviteFrame.playerList.lines[textline].zoneText = zoneText

			local signupText = self.InviteFrame.playerList:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			signupText:SetFont("Friz Quadrata TT", 14)
			signupText:SetPoint("LEFT", left, "RIGHT", 5, 0)
			self.InviteFrame.playerList.lines[textline].signupText = signupText

			local onlineText = self.InviteFrame.playerList:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			onlineText:SetFont("Friz Quadrata TT", 14)
			onlineText:SetPoint("LEFT", left, "RIGHT", 5, 0)
			self.InviteFrame.playerList.lines[textline].onlineText = onlineText

			local inviteText = self.InviteFrame.playerList:CreateFontString(nil, "OVERLAY", "GameFontNormal")
			inviteText:SetFont("Friz Quadrata TT", 14)
			inviteText:SetPoint("LEFT", left, "RIGHT", 5, 0)
			self.InviteFrame.playerList.lines[textline].inviteText = inviteText
		end
		local player = self:GetPlayer(i)
		if player then
			self.InviteFrame.playerList.lines[textline].nameText:SetText(player.name)
			self.InviteFrame.playerList.lines[textline].classText:SetText(player.class)
			self.InviteFrame.playerList.lines[textline].rankText:SetText(player.rank)
			self.InviteFrame.playerList.lines[textline].zoneText:SetText(player.zone)
			self.InviteFrame.playerList.lines[textline].signupText:SetText(player.signupStatus)
			if player.online then
				self.InviteFrame.playerList.lines[textline].onlineText:SetText("Online "..player.status)
			else
				self.InviteFrame.playerList.lines[textline].onlineText:SetText("Offline")
			end
			self.InviteFrame.playerList.lines[textline].inviteText:SetText(player.inviteStatus)
		else
			self:ClearListRow(textline)
		end
		textHeight = self.InviteFrame.playerList.lines[textline]:GetHeight()
	end
	for i = textline + 1, 25 do
		if self.InviteFrame.playerList.lines[i] then
			self:ClearListRow(textline)
		end
	end
--~ 	self.InviteFrame.playerList.scroll:SetWidth(960)
--~ 	self.InviteFrame.playerList.scroll:SetHeight(20 * (textHeight + 1))
--~ 	self.InviteFrame.playerList:SetWidth(1000)
--~ 	self.InviteFrame.playerList:SetHeight(20 * (textHeight + 1) + 120)
	self.InviteFrame.playerList:Show()
end

function RaidInviter:ClearListRow(textline)
	self.InviteFrame.playerList.lines[textline].nameText:SetText("")
	self.InviteFrame.playerList.lines[textline].classText:SetText("")
	self.InviteFrame.playerList.lines[textline].rankText:SetText("")
	self.InviteFrame.playerList.lines[textline].ZoneText:SetText("")
	self.InviteFrame.playerList.lines[textline].signupText:SetText("")
	self.InviteFrame.playerList.lines[textline].onlineText:SetText("")
	self.InviteFrame.playerList.lines[textline].inviteText:SetText("")
end

function RaidInviter:CreateRaidCompositionFrames()
	if not self.InviteFrame.raidRoleComposition then
		self.InviteFrame.raidRoleComposition = CreateFrame("Frame", "RaidInviterRoleComposition", self.InviteFrame)
	end
	if not self.InviteFrame.raidClassComposition then
		self.InviteFrame.raidClassComposition = CreateFrame("Frame", "RaidInviterClassComposition", self.InviteFrame)
	end
end

function RaidInviter:RaidInviter_OnHide()
	self.InviteFrame:Hide()
end

function RaidInviter:RaidInviter_OnShow()
	self.InviteFrame:Show()
end

function RaidInviter:EventListItem_OnClick()
	CalendarOpenEvent(0, self.day, this.value)	
	UIDropDownMenu_SetSelectedValue(this.owner, this.value)
	local guildRoster = self:LoadGuildRoster()
	local title, hour, minute, _, _, _, texture, _, _, _, difficulty = CalendarGetDayEvent( 0, self.day, this.value )
	self:DebugPrint("setting event to "..this.value.." title:"..title.." time "..hour..":"..minute)
	if not self.todaysEvents then
		self.todaysEvents = {}
	end
	if not self.todaysEvents[this.value] then
		self.todaysEvents[this.value] = {}
	end
	self.todaysEvents[this.value].index = this.value
	self.todaysEvents[this.value].title = title
	self.todaysEvents[this.value].hour = hour
	self.todaysEvents[this.value].minute = minute
	self.todaysEvents[this.value].texture = texture
	self.todaysEvents[this.value].difficulty = difficulty
	self.selectedEvent = self.todaysEvents[this.value]
	self.InviteFrame.event.title:SetText("Event : "..self.selectedEvent.title)
	self.InviteFrame.event.time:SetText("Time : "..self.selectedEvent.hour..":"..self.selectedEvent.minute)
	self:DebugPrint("texture : Interface\\LFGFrame\\LFGIcon-"..self.selectedEvent.texture)
	self:SetEventIcon("Interface\\LFGFrame\\LFGIcon-"..self.selectedEvent.texture)
end

function RaidInviter:LoadGuildRoster()
	self.guildRoster = {}
	if IsInGuild() then
		GuildRoster()
	end
end

function RaidInviter:UpdateInviteFrame()

end

function RaidInviter:UpdateInviteFrameWithGuildInfo()
	-- this function will update the raidInvites zone, online & afk/dnd status, 
	for name,player in ipairs(self.selectedEvent.players) do
		self:DebugPrint("updating frame with guild info for "..name)
		if self.guildRoster[name] and self.selectedEvent then
			if self.selectedEvent.players[name] then
				player.guildRank = self.guildRoster[name].rank
				player.note = self.guildRoster[name].note
				player.officernote = self.guildRoster[name].officernote
				player.zone = self.guildRoster[name].zone
				player.online = self.guildRoster[name].online
				player.status = self.guildRoster[name].status
				player.lastonline = self.guildRoster[name].lastonline
			else
				self:Print("called updateInviteFrameWithGuildInfo and didn't find "..name)
			end
		end
	end
end

-------------------------
-- Utilitiy Functions
-------------------------

function RaidInviter:DebugPrint(msg)
	if self.db.char.debug then
		self:Print(msg)
	end
end

function RaidInviter:GetPlayer(searchIndex)
	for name,player in ipairs(self.selectedEvent.players) do
		if player and player.index == searchIndex then
			return player
		end
	end
	return nil
end
